import { graphql } from "@/gql";
import { EventFragment } from "@/gql/graphql";
import { getClient } from "@/app/client";
import { Blocks } from "@/components/blocks/Blocks";

export async function generateStaticParams() {
  const allEventSlugsQuery = graphql(`
    query allEventSlugs {
      pages(contentType: "events.EventPage") {
        id
        slug
      }
    }
  `);
  const { data } = await getClient().query(allEventSlugsQuery);

  return data?.pages.map((page: any) => ({
    slug: page.slug,
  }));
}

export default async function Page({ params }: { params: { slug: string } }) {
  const eventBySlugQuery = graphql(`
    query eventBySlug($slug: String!) {
      event: page(contentType: "events.EventPage", slug: $slug) {
        ... on EventPage {
          ...Event
        }
      }
    }
  `);

  const { data, error } = await getClient().query(eventBySlugQuery, {
    slug: params.slug,
  });

  // console.log('data', data)
  // console.log('error', error)

  const event = (data?.event ?? {}) as EventFragment;

  console.log("event", event);

  return (
    <main className="site-main" id="main">
      <section className="page-header">
        <h1>{event.title}</h1>
      </section>
      <section className="page-content">
        <Blocks blocks={event.body} />
        <div>Facebook: {event.facebookUrl}</div>
        <div>Billettlenke: {event.ticketUrl}</div>
        <div>Ordinær pris: {event.priceRegular}</div>
        <div>Studentpris: {event.priceStudent}</div>
        <div>Medlemspris: {event.priceMember}</div>
      </section>
    </main>
  );
}
