import { graphql } from "@/gql";
import { EventFragment } from "@/gql/graphql";
import { getClient } from "@/app/client";
import { EventList } from "@/components/events/EventList";

const EventFragmentDefinition = graphql(`
  fragment Event on EventPage {
    __typename
    id
    slug
    title
    body {
      id
      blockType
      field
      ... on RichTextBlock {
        rawValue
        value
      }
    }
    featuredImage {
      src
    }
    facebookUrl
    ticketUrl
    priceRegular
    priceMember
    priceStudent
  }
`);

export default async function Page() {
  const allEventsQuery = graphql(`
    query allEvents {
      events: pages(contentType: "events.EventPage") {
        ... on EventPage {
          ...Event
        }
      }
    }
  `);
  const { data, error } = await getClient().query(allEventsQuery, {});
  const events = (data?.events ?? []) as EventFragment[]

  return (
    <main className="site-main" id="main">
      <section className="page-header">
        <h1>Arrangementer</h1>
      </section>
      <EventList events={events} />
    </main>
  );
}
